@@ -386,7 +386,7 @@ setup_merge_directory(void)
 {
 	int len;
 
-	merge_main_dir = gnome_datadir_file("gnome/apps/");
+	merge_main_dir = gnome_datadir_file("gnome/apps");
 	merge_main_dir_len = merge_main_dir != NULL ? strlen (merge_main_dir) : 0;
 	merge_merge_dir = conditional_get_string ("/panel/Merge/Directory",
 						  "/etc/X11/applnk/",
@@ -418,8 +418,9 @@ setup_visuals (void)
 static void
 kill_free_drawers (void)
 {
-	GSList *li;
-	for (li = panel_list; li != NULL; li = li->next) {
+	GSList *li, *list;
+	list = g_slist_copy (panel_list); 
+	for (li = list; li != NULL; li = li->next) {
 		PanelData *pd = li->data;
 		if (IS_DRAWER_WIDGET (pd->panel) &&
 		    PANEL_WIDGET (BASEP_WIDGET (pd->panel)->panel)->master_widget == NULL) {
@@ -427,6 +428,7 @@ kill_free_drawers (void)
 			gtk_widget_destroy (pd->panel);
 		}
 	}
+	g_slist_free(list);
 }
 
 /* gets a GdkPixmap for a given X atom name whose value is an X Pixmap */
@@ -445,16 +447,22 @@ get_pixmap_prop (char *prop_id)
 		return NULL;
 	}
 
+	data = NULL;
 	XGetWindowProperty(GDK_DISPLAY(), GDK_ROOT_WINDOW(), prop, 0L, 1L, 
 			False, AnyPropertyType, &type, &format, &length, 
 			&after, &data);
 
 	if (type != XA_PIXMAP) {
+		if (data)
+			XFree(data);
 		return NULL;
 	}
 
 	p = *((Pixmap *)data);
 
+	if (data)
+    		XFree(data);
+
 	/* remember not to unref this pixmap */
 	return gdk_pixmap_foreign_new(p);
 }
@@ -589,6 +597,8 @@ main(int argc, char **argv)
 	panel_tooltips = gtk_tooltips_new ();
 
 	xstuff_init ();
+	status_applet_create_offscreen ();
+
 	multiscreen_init ();
 
 	gnome_win_hints_init ();
@@ -606,8 +616,6 @@ main(int argc, char **argv)
 	if ( ! commie_mode)
 		write_global_config ();
 
-	gwmh_init ();
-
 	init_fr_chunks ();
 	
 	init_menus ();
@@ -646,8 +654,6 @@ main(int argc, char **argv)
 	  starting multiple goad_id's at once are libgnorba's problem*/
 	load_queued_externs ();
 
-	status_applet_create_offscreen ();
-
 	gtk_main ();
 
 	return 0;
